import { login, logout, getInfo } from "@/api/login";
import { getToken, setToken, removeToken } from "@/utils/auth";
import { getSchoolListApi } from "@/api/smartCampus/index";
import defAva from "@/assets/images/profile.jpg";
import usePaperStore from "@/store/modules/paper";

const useUserStore = defineStore("user", {
  state: () => ({
    token: getToken(),
    id: "",
    name: "",
    avatar: "",
    nickName: "",
    roles: [],
    permissions: [],
    schoolList: [],
    showAllTenant: false,
  }),
  actions: {
    // 登录
    login(userInfo) {
      const username = userInfo.username.trim();
      const password = userInfo.password;
      const code = userInfo.code;
      const uuid = userInfo.uuid;
      return new Promise((resolve, reject) => {
        login(username, password, code, uuid)
          .then((res) => {
            setToken(res.data.token);
            this.token = res.data.token;
            resolve();
          })
          .catch((error) => {
            reject(error);
          });
      });
    },
    // 获取用户信息
    getInfo() {
      return new Promise((resolve, reject) => {
        getInfo()
          .then((res) => {
            const user = res.data.user;
            this.showAllTenant = res.data.showAllTenant;
            const avatar =
              user.avatar == "" || user.avatar == null ? defAva : user.avatar;
            if (res.data.roles && res.data.roles.length > 0) {
              // 验证返回的roles是否是一个非空数组
              this.roles = res.data.roles;
              this.permissions = res.data.permissions;
            } else {
              this.roles = ["ROLE_DEFAULT"];
            }
            this.id = user.userId;
            this.name = user.userName;
            this.nickName = user.nickName;
            this.avatar = avatar;
            if (this.showAllTenant) {
              this.getSchoolList();
            }
            resolve(res);
          })
          .catch((error) => {
            reject(error);
          });
      });
    },
    // 超管角色获取学校列表
    getSchoolList(data) {
      return new Promise((resolve, reject) => {
        getSchoolListApi(data)
          .then((res) => {
            this.schoolList = res.rows;
            resolve(res);
          })
          .catch((error) => {
            reject(error);
          });
      });
    },
    // 退出系统
    logOut() {
      const { clearSearch } = usePaperStore();
      return new Promise((resolve, reject) => {
        logout(this.token)
          .then(() => {
            this.token = "";
            this.roles = [];
            this.permissions = [];
            clearSearch(true);
            removeToken();
            resolve();
          })
          .catch((error) => {
            reject(error);
          });
      });
    },
  },
});

export default useUserStore;
